@@ -1,11 +1,11 @@
 ;;; org-modern.el --- Modern looks for Org -*- lexical-binding: t -*-
 
-;; Copyright (C) 2022-2024 Free Software Foundation, Inc.
+;; Copyright (C) 2022-2025 Free Software Foundation, Inc.
 
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.6
+;; Version: 1.7
 ;; Package-Requires: ((emacs "28.1") (compat "30"))
 ;; URL: https://github.com/minad/org-modern
 ;; Keywords: outlines, hypermedia, text
@@ -674,14 +674,14 @@ whole buffer; otherwise, for the line at point."
    'org-modern-label nil
    :box
    (when org-modern-label-border
-     (let ((border (if (eq org-modern-label-border 'auto)
-                       (max 2 (cond
-                               ((integerp line-spacing)
-                                line-spacing)
-                               ((floatp line-spacing)
-                                (ceiling (* line-spacing (frame-char-height))))
-                               (t (/ (frame-char-height) 10))))
-                     org-modern-label-border)))
+     (let ((border (if (integerp org-modern-label-border)
+                       org-modern-label-border
+                     (max 2 (cond
+                             ((integerp line-spacing)
+                              line-spacing)
+                             ((floatp line-spacing)
+                              (ceiling (* line-spacing (frame-char-height))))
+                             (t (/ (frame-char-height) 10)))))))
        (list :color (face-attribute 'default :background nil t)
              :line-width (cons -1 (- border)))))))
 
@@ -786,6 +786,7 @@ whole buffer; otherwise, for the line at point."
             ('t '(1 '(face nil invisible org-modern)))
             ((pred stringp) `(1 '(face nil display ,org-modern-keyword)))
             (_ '(0 (org-modern--keyword)))))))
+   ;; Timestamps can come after keywords
    (when org-modern-timestamp
      '(("\\(?:<\\|^\\[\\|[^]]\\[\\)\\([0-9]\\{4\\}-[0-9]\\{2\\}-[0-9]\\{2\\}\\(?: [[:word:]]+\\.?\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(\\(?: [0-9:-]+\\)?\\(?: [.+-]+[0-9ymwdh/]+\\)*\\)\\(?:>\\|\\]\\)"
         (0 (org-modern--timestamp)))
@@ -816,7 +817,9 @@ whole buffer; otherwise, for the line at point."
        `(("^\\([ \t]*\\)\\(#\\+\\(?:begin\\|BEGIN\\)_\\)\\(\\S-+\\).*"
           ,@(car specs))
          ("^\\([ \t]*\\)\\(#\\+\\(?:end\\|END\\)_\\)\\(\\S-+\\).*"
-          ,@(cdr specs)))))))
+          ,@(cdr specs)))))
+   (when (fboundp 'org-activate-folds)
+     '(org-activate-folds))))
 
 ;;;###autoload
 (define-minor-mode org-modern-mode
@@ -845,7 +848,9 @@ whole buffer; otherwise, for the line at point."
      (mapcar (pcase-lambda (`(,k . ,v)) (cons k (org-modern--symbol v)))
              org-modern-checkbox)
      org-modern--font-lock-keywords
-     (append (remove '(org-fontify-meta-lines-and-blocks) org-font-lock-keywords)
+     (append (remove '(org-fontify-meta-lines-and-blocks)
+                     (remove '(org-activate-folds)
+                             org-font-lock-keywords))
              (org-modern--make-font-lock-keywords)))
     (font-lock-remove-keywords nil org-font-lock-keywords)
     (font-lock-add-keywords nil org-modern--font-lock-keywords)
